@@ -98,9 +98,17 @@ typedef enum
   C_DESKTOP_MAGNIFIER_SCREEN_POSITION_TOP_HALF,
   C_DESKTOP_MAGNIFIER_SCREEN_POSITION_BOTTOM_HALF,
   C_DESKTOP_MAGNIFIER_SCREEN_POSITION_LEFT_HALF,
-  C_DESKTOP_MAGNIFIER_SCREEN_POSITION_RIGHT_HALF,
+  C_DESKTOP_MAGNIFIER_SCREEN_POSITION_RIGHT_HALF
 } CDesktopMagnifierScreenPosition;
 
+typedef enum
+{
+  C_DESKTOP_MAGNIFIER_LENS_SHAPE_NONE,
+  C_DESKTOP_MAGNIFIER_LENS_SHAPE_SQUARE,
+  C_DESKTOP_MAGNIFIER_LENS_SHAPE_HORIZONTAL,
+  C_DESKTOP_MAGNIFIER_LENS_SHAPE_VERTICAL
+} CDesktopMagnifierLensShape;
+
 typedef enum
 {
   C_DESKTOP_TITLEBAR_ACTION_TOGGLE_SHADE = 0,
@@ -127,19 +135,19 @@ typedef enum
 {
   C_DESKTOP_FOCUS_MODE_CLICK,
   C_DESKTOP_FOCUS_MODE_SLOPPY,
-  C_DESKTOP_FOCUS_MODE_MOUSE,
+  C_DESKTOP_FOCUS_MODE_MOUSE
 } CDesktopFocusMode;
 
 typedef enum
 {
   C_DESKTOP_FOCUS_NEW_WINDOWS_SMART,
-  C_DESKTOP_FOCUS_NEW_WINDOWS_STRICT,
+  C_DESKTOP_FOCUS_NEW_WINDOWS_STRICT
 } CDesktopFocusNewWindows;
 
 typedef enum
 {
   C_DESKTOP_VISUAL_BELL_FULLSCREEN_FLASH,
-  C_DESKTOP_VISUAL_BELL_FRAME_FLASH,
+  C_DESKTOP_VISUAL_BELL_FRAME_FLASH
 } CDesktopVisualBellType;
 
 typedef enum
@@ -157,8 +165,6 @@ typedef enum
         C_DESKTOP_MEDIA_KEY_MIC_MUTE,
         C_DESKTOP_MEDIA_KEY_EJECT,
         C_DESKTOP_MEDIA_KEY_MEDIA,
-        C_DESKTOP_MEDIA_KEY_SCREENSHOT,
-        C_DESKTOP_MEDIA_KEY_WINDOW_SCREENSHOT,
         C_DESKTOP_MEDIA_KEY_PLAY,
         C_DESKTOP_MEDIA_KEY_PAUSE,
         C_DESKTOP_MEDIA_KEY_STOP,
@@ -168,15 +174,17 @@ typedef enum
         C_DESKTOP_MEDIA_KEY_FORWARD,
         C_DESKTOP_MEDIA_KEY_REPEAT,
         C_DESKTOP_MEDIA_KEY_RANDOM,
-        C_DESKTOP_MEDIA_KEY_AREA_SCREENSHOT,
+        C_DESKTOP_MEDIA_KEY_SCREENSHOT,
         C_DESKTOP_MEDIA_KEY_SCREENSHOT_CLIP,
-        C_DESKTOP_MEDIA_KEY_WINDOW_SCREENSHOT_CLIP,
-        C_DESKTOP_MEDIA_KEY_AREA_SCREENSHOT_CLIP,
 
         C_DESKTOP_MEDIA_KEY_SEPARATOR,
 /* The rest are normal priority - they won't trigger during
    a modal Cinnamon state
  */
+        C_DESKTOP_MEDIA_KEY_WINDOW_SCREENSHOT,
+        C_DESKTOP_MEDIA_KEY_WINDOW_SCREENSHOT_CLIP,
+        C_DESKTOP_MEDIA_KEY_AREA_SCREENSHOT,
+        C_DESKTOP_MEDIA_KEY_AREA_SCREENSHOT_CLIP,
         C_DESKTOP_MEDIA_KEY_TOUCHPAD,
         C_DESKTOP_MEDIA_KEY_TOUCHPAD_ON,
         C_DESKTOP_MEDIA_KEY_TOUCHPAD_OFF,
@@ -192,6 +200,7 @@ typedef enum
         C_DESKTOP_MEDIA_KEY_WWW,
         C_DESKTOP_MEDIA_KEY_VIDEO_OUT,
         C_DESKTOP_MEDIA_KEY_ROTATE_VIDEO,
+        C_DESKTOP_MEDIA_KEY_ROTATE_VIDEO_LOCK,
         C_DESKTOP_MEDIA_KEY_SCREENREADER,
         C_DESKTOP_MEDIA_KEY_ON_SCREEN_KEYBOARD,
         C_DESKTOP_MEDIA_KEY_INCREASE_TEXT,
@@ -252,6 +261,7 @@ __attribute__((unused)) static const char *media_keys[] = {
         [C_DESKTOP_MEDIA_KEY_WWW] = "www",
         [C_DESKTOP_MEDIA_KEY_VIDEO_OUT] = "video-outputs",
         [C_DESKTOP_MEDIA_KEY_ROTATE_VIDEO] = "video-rotation",
+        [C_DESKTOP_MEDIA_KEY_ROTATE_VIDEO_LOCK] = "video-rotation-lock",
         [C_DESKTOP_MEDIA_KEY_SCREENREADER] = "screenreader",
         [C_DESKTOP_MEDIA_KEY_ON_SCREEN_KEYBOARD] = "on-screen-keyboard",
         [C_DESKTOP_MEDIA_KEY_INCREASE_TEXT] = "increase-text-size",
