@@ -45,7 +45,6 @@
 #include "gnome-desktop-thumbnail.h"
 #include "gnome-desktop-utils.h"
 #include <glib/gstdio.h>
-#include <libgsystem.h>
 
 #define SECONDS_BETWEEN_STATS 10
 
@@ -179,6 +178,20 @@ thumbnailer_load (Thumbnailer *thumb)
     }
 
   thumb->try_exec = g_key_file_get_string (key_file, THUMBNAILER_ENTRY_GROUP, "TryExec", NULL);
+  if (thumb->try_exec != NULL)
+    {
+      gchar *path_to_exec = g_find_program_in_path (thumb->try_exec);
+
+      if (path_to_exec == NULL)
+        {
+          g_message ("Ignoring thumbnailer with missing binary: '%s'", thumb->try_exec);
+          thumbnailer_unref (thumb);
+          g_key_file_free (key_file);
+          return NULL;
+        }
+
+      g_free (path_to_exec);
+    }
 
   g_key_file_free (key_file);
 
@@ -212,28 +225,6 @@ thumbnailer_new (const gchar *path)
   return thumbnailer_load (thumb);
 }
 
-static gboolean
-thumbnailer_try_exec (Thumbnailer *thumb)
-{
-  gchar *path;
-  gboolean retval;
-
-  if (G_UNLIKELY (!thumb))
-    return FALSE;
-
-  /* TryExec is optinal, but Exec isn't, so we assume
-   * the thumbnailer can be run when TryExec is not present
-   */
-  if (!thumb->try_exec)
-    return TRUE;
-
-  path = g_find_program_in_path (thumb->try_exec);
-  retval = path != NULL;
-  g_free (path);
-
-  return retval;
-}
-
 static gpointer
 init_thumbnailers_dirs (gpointer data)
 {
@@ -386,7 +377,7 @@ _gdk_pixbuf_new_from_uri_at_scale (const char *uri,
     }
 
     if (input_stream == NULL) {
-        input_stream = gs_file_read_noatime (file, NULL, &error);
+        input_stream = G_INPUT_STREAM (g_file_read (file, NULL, &error));
         if (input_stream == NULL) {
             if (error != NULL) {
                 g_warning ("Unable to create an input stream for %s: %s", uri, error->message);
@@ -495,7 +486,12 @@ gnome_desktop_thumbnail_factory_finalize (GObject *object)
 
   priv = factory->priv;
 
-  g_clear_pointer (&priv->thumbnailers, thumbnailer_unref);
+  if (priv->thumbnailers)
+    {
+      g_list_free_full (priv->thumbnailers, (GDestroyNotify)thumbnailer_unref);
+      priv->thumbnailers = NULL;
+    }
+
   g_clear_pointer (&priv->mime_types_map, g_hash_table_destroy);
 
   if (priv->monitors)
@@ -1083,9 +1079,6 @@ gnome_desktop_thumbnail_factory_can_thumbnail (GnomeDesktopThumbnailFactory *fac
 					       const char            *mime_type,
 					       time_t                 mtime)
 {
-  gboolean have_script = FALSE;
-
-
   if (factory->priv->permissions_problem)
     return FALSE;
 
@@ -1107,11 +1100,10 @@ gnome_desktop_thumbnail_factory_can_thumbnail (GnomeDesktopThumbnailFactory *fac
 
   Thumbnailer *thumb;
   thumb = g_hash_table_lookup (factory->priv->mime_types_map, mime_type);
-  have_script = thumbnailer_try_exec (thumb);
 
   g_mutex_unlock (&factory->priv->lock);
 
-  if (have_script || mimetype_supported_by_gdk_pixbuf (mime_type))
+  if (thumb || mimetype_supported_by_gdk_pixbuf (mime_type))
     {
       return !gnome_desktop_thumbnail_factory_has_valid_failed_thumbnail (factory,
                                                                           uri,
